@@ -9,9 +9,11 @@
 # MG 9.3.2010
 # IS 1.11.2010, small fix to column matching
 # JTT 30.3.2010, added a parameter to control matching
+# modified, IS, 12.10.2012, to cope with tables with gene descriptions (that typically contain 's)
 
 # Loads the normalized data
-dat <- read.table('normalized.tsv', header=TRUE, sep='\t', quote='', check.names=FALSE)
+file <- 'normalized.tsv'
+dat <- read.table(file, header=TRUE, sep='\t', quote='', row.names=1, check.names=FALSE)
 
 # Only exact matches?
 if(exact.match=="yes") {
@@ -22,7 +24,7 @@ if(exact.match=="yes") {
 dat2 <- dat[grep(match.term, dat[,column]),]
 
 # write output
+options(scipen=10)
 write.table(dat2, 'column-term-filter.tsv', sep='\t', quote=FALSE)
+
 # EOF
-
-
