@@ -16,11 +16,11 @@
 # PARAMETER image.width: image.width TYPE INTEGER FROM 200 TO 6400 DEFAULT 2400 (Width of the plotted network image)
 # PARAMETER image.height: image.height TYPE INTEGER FROM 200 TO 6400 DEFAULT 2400 (Height of the plotted network image)
 
-# sample-size-with-bh.R
 # Ilari Scheinin <firstname.lastname@gmail.com>
-# 2011-03-28
+# 2012-10-12
 
-dat <- read.table('normalized.tsv', header=TRUE, sep='\t', as.is=TRUE, row.names=1)
+file <- 'normalized.tsv'
+dat <- read.table(file, header=TRUE, sep='\t', quote='', row.names=1, check.names=FALSE)
 phenodata <- read.table("phenodata.tsv", header=TRUE, sep="\t")
 groups <- phenodata[,column]
 
@@ -395,6 +395,7 @@ plot(samplesize, power, type='b', main=paste('Power calculation for FDR = ', rou
   xlab=paste('Number of samples (', round(100*N1/(N1+N2)), '% ', class.names[1], ', ', round(100*N2/(N1+N2)), '% ', class.names[2], ')', sep=''))
 dev.off()
 #
+options(scipen=10)
 write.table(data.frame(samplesize, power), file="power.txt", quote=FALSE, col.names=TRUE, row.names=FALSE, sep='\t')
 #
 ################################################################################################################################################
