@@ -3,8 +3,8 @@ package fi.csc.chipster.tools.ngs.regions;
 import java.util.LinkedList;
 import java.util.List;
 
-import fi.csc.chipster.tools.gbrowser.regions.RegionOperations;
 import fi.csc.microarray.client.visualisation.methods.gbrowser.message.RegionContent;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.util.RegionOperations;
 
 public class CombineRegionsTool extends RegionTool {
 
